@@ -18,17 +18,16 @@
 #
 #=============================================================================
 
-package Term::CLI  0.053006 {
+package Term::CLI 0.054001;
 
 use 5.014;
-use strict;
 use warnings;
 
 use Text::ParseWords 3.27 qw( parse_line );
 use Term::CLI::ReadLine;
 use FindBin 1.50;
 
-use Term::CLI::L10N;
+use Term::CLI::L10N qw( loc );
 
 # Load all Term::CLI classes so the user doesn't have to.
 
@@ -60,43 +59,44 @@ extends 'Term::CLI::Base';
 
 with('Term::CLI::Role::CommandSet');
 
+my $DFL_HIST_SIZE = 1000;
+my $ERROR_STATUS  = -1;
+
 # Provide a default for 'name'.
-has '+name' => (
-    default => sub { $FindBin::Script }
-);
+has '+name' => ( default => sub {$FindBin::Script} );
 
 has cleanup => (
     is        => 'rw',
-    isa       => Maybe[CodeRef],
+    isa       => Maybe [CodeRef],
     predicate => 1
 );
 
 has prompt => (
-    is => 'rw',
-    isa => Str,
-    default => sub { '~> ' }
+    is      => 'rw',
+    isa     => Str,
+    default => sub {'~> '}
 );
 
 has split_function => (
-    is => 'rw',
-    isa => CodeRef,
+    is      => 'rw',
+    isa     => CodeRef,
     default => sub { \&_default_split }
 );
 
 has skip => (
-    is => 'rw',
+    is  => 'rw',
     isa => RegexpRef,
 );
 
 has history_file => (
-    is => 'rw',
+    is  => 'rw',
     isa => Str
 );
 
 has history_lines => (
-    is => 'rw',
-    isa => Int,
-    default => sub { 1000 },
+    is      => 'rw',
+    isa     => Int,
+    default => sub {$DFL_HIST_SIZE},
     trigger => 1,
 );
 
@@ -104,28 +104,28 @@ has word_delimiters  => ( is => 'rw', isa => Str, default => sub {" \n\t"} );
 has quote_characters => ( is => 'rw', isa => Str, default => sub {q("')} );
 
 sub BUILD {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
-    my $term = Term::CLI::ReadLine->new($self->name)->term;
+    my $term = Term::CLI::ReadLine->new( $self->name )->term;
 
-    if (my $sig_list = $args->{ignore_keyboard_signals}) {
-        $term->ignore_keyboard_signals(@$sig_list);
+    if ( my $sig_list = $args->{ignore_keyboard_signals} ) {
+        $term->ignore_keyboard_signals( @{$sig_list} );
     }
 
     $term->Attribs->{completion_function} = sub { $self->complete_line(@_) };
-    $term->Attribs->{char_is_quoted_p} = sub { $self->_is_escaped(@_) };
+    $term->Attribs->{char_is_quoted_p}    = sub { $self->_is_escaped(@_) };
 
     $self->_set_completion_attribs;
 
-    if (! exists $args->{callback} ) {
-        $self->callback(\&_default_callback);
+    if ( !exists $args->{callback} ) {
+        $self->callback( \&_default_callback );
     }
 
-    if (!exists $args->{history_file}) {
+    if ( !exists $args->{history_file} ) {
         my $hist_file = $self->name;
-        $hist_file =~ s{^/}{}g;
-        $hist_file =~ s{/$}{}g;
-        $hist_file =~ s{/+}{-}g;
+        $hist_file =~ s{^/}{}gx;
+        $hist_file =~ s{/$}{}gx;
+        $hist_file =~ s{/+}{-}gx;
         $self->history_file("$::ENV{HOME}/.${hist_file}_history");
     }
 
@@ -134,23 +134,26 @@ sub BUILD {
     # *is* called, but it happens *before* the `$term` is
     # initialised; and if no history_lines is given, the
     # trigger is not called for the default.
-    $self->history_lines($self->history_lines);
+    $self->history_lines( $self->history_lines );
+    return;
 }
 
 sub DEMOLISH {
     my ($self) = @_;
-    if ($self->has_cleanup) {
+    if ( $self->has_cleanup ) {
         $self->cleanup->($self);
     }
+    return;
 }
 
-sub _trigger_history_lines {
-    my ($self, $arg) = @_;
+sub _trigger_history_lines {    ## no critic (ProhibitUnusedPrivateSubroutines)
+    my ( $self, $arg ) = @_;
 
     # Terminal may not be initialiased yet...
     return if !$self->term;
 
     $self->term->StifleHistory($arg);
+    return;
 }
 
 # %args = $self->_default_callback(%args);
@@ -159,15 +162,14 @@ sub _trigger_history_lines {
 # Simply check the status and print an error
 # message if status < 0.
 sub _default_callback {
-    my ($self, %args) = @_;
+    my ( $self, %args ) = @_;
 
-    if ($args{status} < 0) {
+    if ( $args{status} < 0 ) {
         say STDERR loc("ERROR"), ": ", $args{error};
     }
     return %args;
 }
 
-
 # ($error, @words) = $self->_default_split($text);
 #
 # Default function to split a string into words.
@@ -178,35 +180,38 @@ sub _default_callback {
 # quote characters.
 #
 sub _default_split {
-    my ($self, $text) = @_;
+    my ( $self, $text ) = @_;
 
-    if ($text =~ /\S/) {
-        my $delim = $self->word_delimiters;
-        $text =~ s/^[$delim]+//;
-        my @words = parse_line(qr{[$delim]+}, 0, $text);
-        pop @words if @words and not defined $words[-1];
-        my $error = @words ? '' : loc('unbalanced quotes in input');
-        return ($error, @words);
-    }
-    else {
-        return ('');
+    my $delim = $self->word_delimiters;
+
+    $text =~ s/^ [$delim]+ //gxsm; # Strip leading delimiters.
+
+    return (q{}) if length $text == 0; # Blank line.
+
+    my @words = parse_line( qr{ [$delim]+ }xms, 0, $text );
+
+    return ( loc('unbalanced quotes in input') ) if !@words;
+
+    # If the text ends in one or more delimiters, the last word will be
+    # "undef", but it's not an errror, so just eliminate it.
+    if ( @words > 0 && !defined $words[-1] ) {
+        pop @words;
     }
+    return ( q{}, @words );
 }
 
-
 # BOOL = CLI->_is_escaped($line, $index);
 #
 # The character at $index in $line is a possible word break
 # character. Check if it is perhaps escaped.
 #
 sub _is_escaped {
-    my ($self, $line, $index) = @_;
-    return 0 if !$index or $index < 0;
-    return 0 if substr($line, $index-1, 1) ne '\\';
-    return !$self->_is_escaped($line, $index-1);
+    my ( $self, $line, $index ) = @_;
+    return 0 if not defined $index or $index <= 0;
+    return 0 if substr( $line, $index - 1, 1 ) ne q{\\};
+    return !$self->_is_escaped( $line, $index - 1 );
 }
 
-
 # CLI->_set_completion_attribs();
 #
 # Set some attributes in the Term::ReadLine object related to
@@ -223,10 +228,11 @@ sub _set_completion_attribs {
     $term->Attribs->{completer_word_break_characters} = $self->word_delimiters;
 
     # Default: <space>
-    $term->Attribs->{completion_append_character}
-        = substr($self->word_delimiters, 0, 1);
-}
+    $term->Attribs->{completion_append_character} =
+        substr( $self->word_delimiters, 0, 1 );
 
+    return;
+}
 
 # CLI->_split_line( $text );
 #
@@ -234,22 +240,21 @@ sub _set_completion_attribs {
 # necessary.
 #
 sub _split_line {
-    my ($self, $text) = @_;
-    return $self->split_function->($self, $text);
+    my ( $self, $text ) = @_;
+    return $self->split_function->( $self, $text );
 }
 
-
 # Dumb wrapper around "Attrib" that allows mocking the
 # `completion_quote_character` state.
 sub _rl_completion_quote_character {
     my ($self) = @_;
-    my $c = $self->term->Attribs->{completion_quote_character} // '';
-    return $c =~ s/\000//gr;
+    my $c = $self->term->Attribs->{completion_quote_character} // q{};
+    return $c =~ s/\000//rgx;
 }
 
 # See POD X<complete_line>
 sub complete_line {
-    my ($self, $text, $line, $start) = @_;
+    my ( $self, $text, $line, $start ) = @_;
 
     $self->_set_completion_attribs;
 
@@ -257,16 +262,19 @@ sub complete_line {
 
     my @words;
 
-    if ($start > 0) {
-        if (length $quote_char) {
+    if ( $start > 0 ) {
+        if ( length $quote_char ) {
+
             # ReadLine thinks the $text to be completed is quoted.
             # The quote character will precede the $start of $text.
             # Make sure we do not include it in the text to break
             # into words...
-            (my $err, @words) = $self->_split_line(substr($line, 0, $start-1));
+            ( my $err, @words ) =
+                $self->_split_line( substr( $line, 0, $start - 1 ) );
         }
         else {
-            (my $err, @words) = $self->_split_line(substr($line, 0, $start));
+            ( my $err, @words ) =
+                $self->_split_line( substr( $line, 0, $start ) );
         }
     }
 
@@ -274,26 +282,22 @@ sub complete_line {
 
     my @list;
 
-    if (@words == 1) {
-        @list = grep { rindex($_, $words[0], 0) == 0 } $self->command_names;
+    if ( @words == 1 ) {
+        @list = grep { rindex( $_, $words[0], 0 ) == 0 } $self->command_names;
     }
-    elsif (my $cmd = $self->find_command($words[0])) {
-        @list = $cmd->complete_line(@words[1..$#words]);
+    elsif ( my $cmd = $self->find_command( $words[0] ) ) {
+        @list = $cmd->complete_line( @words[ 1 .. $#words ] );
     }
 
+    return @list if length $quote_char; # No need to worry about spaces.
+
     # Escape spaces in reply if necessary.
-    if (length $quote_char) {
-        return @list;
-    }
-    else {
-        my $delim = $self->word_delimiters;
-        return map { s/([$delim])/\\$1/gr } @list;
-    }
+    my $delim = $self->word_delimiters;
+    return map {s/([$delim])/\\$1/rgx} @list;
 }
 
-
-sub readline {
-    my ($self, %args) = @_;
+sub readline {    ## no critic (ProhibitBuiltinHomonyms)
+    my ( $self, %args ) = @_;
 
     my $prompt = $args{prompt} // $self->prompt;
     my $skip   = exists $args{skip} ? $args{skip} : $self->skip;
@@ -301,48 +305,45 @@ sub readline {
     $self->_set_completion_attribs;
 
     my $input;
-    while (defined ($input = $self->term->readline($prompt))) {
+    while ( defined( $input = $self->term->readline($prompt) ) ) {
         next if defined $skip && $input =~ $skip;
         last;
     }
     return $input;
 }
 
-
 sub read_history {
-    my $self = shift;
+    my ( $self, $hist_file ) = @_;
 
-    my $hist_file = @_ ? shift @_ : $self->history_file;
+    $hist_file //= $self->history_file;
 
     $self->term->ReadHistory($hist_file)
         or return $self->set_error("$hist_file: $!");
     $self->history_file($hist_file);
-    $self->set_error('');
+    $self->clear_error;
     return 1;
 }
 
-
 sub write_history {
-    my $self = shift;
+    my ( $self, $hist_file ) = @_;
 
-    my $hist_file = @_ ? shift @_ : $self->history_file;
+    $hist_file //= $self->history_file;
 
     $self->term->WriteHistory($hist_file)
         or return $self->set_error("$hist_file: $!");
     $self->history_file($hist_file);
-    $self->set_error('');
+    $self->clear_error;
     return 1;
 }
 
-
 sub execute {
-    my ($self, $cmd) = @_;
+    my ( $self, $cmd ) = @_;
 
-    my ($error, @cmd) = $self->_split_line($cmd);
+    my ( $error, @cmd ) = $self->_split_line($cmd);
 
     my %args = (
         status       => 0,
-        error        => '',
+        error        => q{},
         command_line => $cmd,
         command_path => [$self],
         unparsed     => \@cmd,
@@ -350,28 +351,25 @@ sub execute {
         arguments    => [],
     );
 
-    return $self->try_callback(%args, status => -1, error => $error)
+    return $self->try_callback( %args, status => $ERROR_STATUS,
+        error => $error )
         if length $error;
 
-    if (@cmd == 0) {
-        $args{error} = loc("missing command");
-        $args{status} = -1;
+    if ( @cmd == 0 ) {
+        $args{error}  = loc("missing command");
+        $args{status} = $ERROR_STATUS;
     }
-    elsif (my $cmd_ref = $self->find_command($cmd[0])) {
-        %args = $cmd_ref->execute(%args,
-            unparsed => [@cmd[1..$#cmd]]
-        );
+    elsif ( my $cmd_ref = $self->find_command( $cmd[0] ) ) {
+        %args = $cmd_ref->execute( %args, unparsed => [ @cmd[ 1 .. $#cmd ] ] );
     }
     else {
-        $args{error} = $self->error;
-        $args{status} = -1;
+        $args{error}  = $self->error;
+        $args{status} = $ERROR_STATUS;
     }
 
     return $self->try_callback(%args);
 }
 
-}
-
 1;
 
 __END__
@@ -384,7 +382,7 @@ Term::CLI - CLI interpreter based on Term::ReadLine
 
 =head1 VERSION
 
-version 0.053006
+version 0.054001
 
 =head1 SYNOPSIS
 
@@ -888,7 +886,7 @@ L<Term::ReadLine::Perl>(3p),
 L<Term::ReadLine>(3p),
 L<Text::ParseWords>(3p),
 L<Types::Standard>(3p).
- 
+
 Inspiration for the custom completion came from:
 L<https://robots.thoughtbot.com/tab-completion-in-gnu-readline>.
 This is an excellent tutorial into the completion mechanics
