@@ -18,10 +18,9 @@
 #
 #=============================================================================
 
-package Term::CLI::Argument::Bool  0.053006 {
+package Term::CLI::Argument::Bool 0.054001;
 
 use 5.014;
-use strict;
 use warnings;
 
 use Types::Standard 1.000005 qw(
@@ -30,7 +29,7 @@ use Types::Standard 1.000005 qw(
     Bool
 );
 
-use Term::CLI::L10N;
+use Term::CLI::L10N qw( loc );
 
 use Moo 1.000001;
 use namespace::clean 0.25;
@@ -38,94 +37,77 @@ use namespace::clean 0.25;
 extends 'Term::CLI::Argument';
 
 has 'true_values' => (
-    is => 'rw',
-    isa => ArrayRef[Str],
+    is      => 'rw',
+    isa     => ArrayRef [Str],
     default => sub { [qw( true 1 )] },
 );
 
 has 'false_values' => (
-    is => 'rw',
-    isa => ArrayRef[Str],
+    is      => 'rw',
+    isa     => ArrayRef [Str],
     default => sub { [qw( false 0 )] },
 );
 
 has 'ignore_case' => (
-    is => 'rw',
-    isa => Bool,
-    default => sub { 1 },
+    is      => 'rw',
+    isa     => Bool,
+    default => sub {1},
 );
 
-
 sub validate {
     my $self  = shift;
     my $value = shift;
 
     defined $self->SUPER::validate($value) or return;
 
-    my ($true, $false);
+    my ( $true, $false );
 
-    if ($self->ignore_case) {
+    if ( $self->ignore_case ) {
         $value = lc $value;
 
-        $true = [ map { lc $_ } @{$self->true_values} ];
-        $false = [ map { lc $_ } @{$self->false_values} ];
+        $true  = [ map {lc} @{ $self->true_values } ];
+        $false = [ map {lc} @{ $self->false_values } ];
     }
     else {
         $true  = $self->true_values;
         $false = $self->false_values;
     }
 
-    my @true_match = grep { rindex($_, $value, 0) == 0 } @$true;
-    my @false_match = grep { rindex($_, $value, 0) == 0 } @$false;
+    my @true_match  = grep { rindex( $_, $value, 0 ) == 0 } @{$true};
+    my @false_match = grep { rindex( $_, $value, 0 ) == 0 } @{$false};
 
     if (@true_match) {
         if (@false_match) {
             return $self->set_error(
-                loc("ambiguous boolean value"
-                    ." (matches ~[[_1]~] and ~[[_2]~])",
-                    join(", ", @true_match),
-                    join(", ", @false_match),
+                loc('ambiguous boolean value'
+                        . ' (matches ~[[_1]~] and ~[[_2]~])',
+                    join( ', ', @true_match ),
+                    join( ', ', @false_match ),
                 )
             );
         }
-        else {
-            return 1;
-        }
-    }
-    elsif (@false_match) {
-        return 0;
+        return 1;
     }
 
-    return $self->set_error(loc("invalid boolean value"));
+    return 0 if @false_match;
+
+    return $self->set_error( loc('invalid boolean value') );
 }
 
-
 sub complete {
-    my ($self, $value) = @_;
+    my ( $self, $value ) = @_;
 
-    my @values = ( @{$self->true_values}, @{$self->false_values} );
+    my @values = ( @{ $self->true_values }, @{ $self->false_values } );
 
-    if (!length $value) {
-        return sort @values;
+    return ( sort @values ) if $value eq q{};
+
+    if ( $self->ignore_case ) {
+        my @matches =
+            grep { substr( lc $_, 0, length $value ) eq lc $value } @values;
+
+        return ( sort map { $value . substr $_, length $value } @matches );
     }
-    else {
-        if ($self->ignore_case) {
-            my @matches
-                = sort
-                    grep
-                        { substr(lc $_, 0, length($value)) eq lc $value }
-                        @values;
-
-            return map { $value.substr($_, length($value)) } @matches;
-        }
-        else {
-            return sort
-                grep { substr($_, 0, length($value)) eq $value } @values;
-        }
-    }
-}
-
-
+    return ( sort grep { substr( $_, 0, length $value ) eq $value } @values );
 }
 
 1;
@@ -140,7 +122,7 @@ Term::CLI::Argument::Bool - class for "boolean" arguments in Term::CLI
 
 =head1 VERSION
 
-version 0.053006
+version 0.054001
 
 =head1 SYNOPSIS
 
