@@ -18,10 +18,9 @@
 #
 #=============================================================================
 
-package Term::CLI::ReadLine  0.053006 {
+package Term::CLI::ReadLine 0.054001;
 
 use 5.014;
-use strict;
 use warnings;
 
 use parent 0.225 qw( Term::ReadLine );
@@ -31,16 +30,17 @@ use Term::ReadKey 2.34 ();
 use namespace::clean 0.25;
 
 my $DFL_HIST_SIZE = 500;
-my $Term = undef;
+my $HIST_LIMIT    = 2**64 - 1;
+my $Term          = undef;
 
 # Since we cannot be sure what type the Term::ReadLine object
 # is (HASH or ARRAY), we'll have to keep some state here.
 
-my $History_Size              = $DFL_HIST_SIZE;
-my @History                   = ();
+my $History_Size = $DFL_HIST_SIZE;
+my @History      = ();
 
 # Keep a filehandle for Term::ReadKey operations.
-my $Term_FH                   = undef;
+my $Term_FH = undef;
 
 # Original_KB_Signals is fetched at `new` time and used to both restore
 # the ControlChars as well as validate given key names: not all
@@ -48,25 +48,26 @@ my $Term_FH                   = undef;
 my %Original_KB_Signals       = ();
 my @Default_Ignore_KB_Signals = qw( QUIT );
 my %Ignore_KB_Signals         = ();
-my %Sig2KeyName = (
+my %Sig2KeyName               = (
     'INT'  => 'INTERRUPT',
     'QUIT' => 'QUIT',
     'TSTP' => 'SUSPEND',
 );
+
 sub new {
-    my $class = shift;
+    my ( $class, @args ) = @_;
 
     return $Term if $Term;
 
-    $Term = bless Term::ReadLine->new(@_), $class;
+    $Term = bless Term::ReadLine->new(@args), $class;
 
-    $Term_FH = -t $Term->IN ? $Term->IN
-                    : -t $Term->OUT ? $Term->OUT : undef;
+    ## no critic (ProhibitInteractiveTest)
+    $Term_FH = -t $Term->OUT ? $Term->OUT : undef;
 
     %Original_KB_Signals = Term::ReadKey::GetControlChars($Term_FH)
         if $Term_FH;
 
-    if (eval { exists $Term->Attribs->{catch_signals} }) {
+    if ( eval { exists $Term->Attribs->{catch_signals} } ) {
         $Term->Attribs->{catch_signals} = 1;
     }
 
@@ -78,89 +79,94 @@ sub new {
 sub term { return $Term }
 
 sub ignore_keyboard_signals {
-    my ($self, @args) = @_;
+    my ( $self, @args ) = @_;
     foreach my $signame (@args) {
         my $charname = $Sig2KeyName{$signame} or next;
-        $Original_KB_Signals{$charname} or next;
-        $Ignore_KB_Signals{$charname} = '';
+        $Original_KB_Signals{$charname}       or next;
+        $Ignore_KB_Signals{$charname} = q{};
     }
+    return;
 }
 
 sub no_ignore_keyboard_signals {
-    my ($self, @args) = @_;
+    my ( $self, @args ) = @_;
     foreach my $signame (@args) {
         my $charname = $Sig2KeyName{$signame} or next;
-        $Original_KB_Signals{$charname} or next;
+        $Original_KB_Signals{$charname}       or next;
         delete $Ignore_KB_Signals{$charname};
     }
+    return;
 }
 
 sub _set_ignore_keyboard_signals {
     my ($self) = @_;
-    return if ! $Term_FH;
-    Term::ReadKey::SetControlChars(%Ignore_KB_Signals, $Term_FH);
+    return if !$Term_FH;
+    Term::ReadKey::SetControlChars( %Ignore_KB_Signals, $Term_FH );
+    return;
 }
 
 sub _restore_keyboard_signals {
     my ($self) = @_;
-    return if ! $Term_FH;
-    Term::ReadKey::SetControlChars(%Original_KB_Signals, $Term_FH);
+    return if !$Term_FH;
+    Term::ReadKey::SetControlChars( %Original_KB_Signals, $Term_FH );
+    return;
 }
 
 sub reset_ignore_keyboard_signals {
     my ($self) = @_;
     %Ignore_KB_Signals = ();
     $self->ignore_keyboard_signals(@Default_Ignore_KB_Signals);
+    return;
 }
 
 sub term_width {
     my $self = shift;
-    my ($rows, $cols) = $self->get_screen_size();
+    my ( $rows, $cols ) = $self->get_screen_size();
     return $cols;
 }
 
 sub term_height {
     my $self = shift;
-    my ($rows, $cols) = $self->get_screen_size();
+    my ( $rows, $cols ) = $self->get_screen_size();
     return $rows;
 }
 
 sub echo_signal_char {
-    my ($self, $sig_arg) = @_;
+    my ( $self, $sig_arg ) = @_;
 
     state $name2int = {
-        'INT' => 2,
+        'INT'  => 2,
         'QUIT' => 3,
         'TSTP' => 20
     };
 
-    if ($self->ReadLine =~ /::Gnu$/) {
-        if ($sig_arg =~ /\D/) {
-            $sig_arg = $$name2int{uc $sig_arg} or return;
+    if ( $self->ReadLine =~ /::Gnu$/x ) {
+        if ( $sig_arg =~ /\D/x ) {
+            $sig_arg = $name2int->{ uc $sig_arg } or return;
         }
         return $self->SUPER::echo_signal_char($sig_arg);
     }
 
-    state $int2name = { reverse %$name2int };
+    state $int2name = { reverse %{$name2int} };
 
-    if ($sig_arg =~ /^\d+$/) {
-        $sig_arg = $$int2name{$sig_arg} or return;
+    if ( $sig_arg =~ /^\d+$/x ) {
+        $sig_arg = $int2name->{$sig_arg} or return;
     }
     $sig_arg = $Sig2KeyName{$sig_arg} // $sig_arg;
     my $char = $Original_KB_Signals{$sig_arg} or return;
-    $char =~ s/([\000-\037])/'^'.chr(ord($1)+ord('@'))/ge;
+    $char =~ s{ ([\000-\037]) }{'^'.chr(ord($1)+ord('@'))}gex;
     $self->OUT->print($char);
 
     return;
 }
 
-sub _escape_str {
-    my ($self, $str) = @_;
-    $str =~ s/\t/\\t/g;
-    $str =~ s/\n/\\n/g;
-    $str =~ s/\r/\\r/g;
-    $str =~ s/([\177-\377])/sprintf("\\%03o", ord($1))/ge;
-    $str =~ s/([\000-\037])/'^'.chr(ord($1)+ord('@'))/ge;
+sub _escape_str {    ## no critic (ProhibitUnusedPrivateSubroutines)
+    my ( $self, $str ) = @_;
+    $str =~ s/\t/\\t/gx;
+    $str =~ s/\n/\\n/gx;
+    $str =~ s/\r/\\r/gx;
+    $str =~ s/([\177-\377])/sprintf("\\%03o", ord($1))/gex;
+    $str =~ s/([\000-\037])/'^'.chr(ord($1)+ord('@'))/gex;
     return $str;
 }
 
@@ -171,13 +177,13 @@ sub _escape_str {
 # implementation handles it, by inserting start/end sequences where
 # necessary.
 sub _prepare_prompt {
-    my ($self, $prompt) = @_;
+    my ( $self, $prompt ) = @_;
 
-    return $prompt if $self->ReadLine !~ /::Gnu$/;
+    return $prompt if $self->ReadLine !~ /::Gnu$/x;
     return $prompt if length $self->Attribs->{term_set}[0] == 0;
 
-    my ($head, $body, $tail) = $prompt =~ /^(\s*)(.*?)(\s*)$/;
-    return $prompt if ($head eq '' and $tail eq '');
+    my ( $head, $body, $tail ) = $prompt =~ /^(\s*)(.*?)(\s*)$/x;
+    return $prompt if ( $head eq q{} and $tail eq q{} );
 
     #say "prompt:       ", $self->_escape_str("<$head><$body><$tail>");
     #say "start_ignore: ", $self->_escape_str($self->RL_PROMPT_START_IGNORE);
@@ -185,42 +191,43 @@ sub _prepare_prompt {
     #say "term_set 0:   ", $self->_escape_str($self->Attribs->{term_set}[0]);
     #say "term_set 1:   ", $self->_escape_str($self->Attribs->{term_set}[1]);
 
-    $prompt = '';
-    if (length $head) {
-        $prompt .= $self->Attribs->{term_set}[1]
-                . $head
-                . $self->Attribs->{term_set}[0]
-                ;
+    $prompt = q{};
+    if ( length $head ) {
+        $prompt
+            .= $self->Attribs->{term_set}[1]
+            . $head
+            . $self->Attribs->{term_set}[0];
     }
+
     #say $self->_escape_str($prompt);
 
     $prompt .= $body;
+
     #say $self->_escape_str($prompt);
 
-    if (length $tail) {
-        $prompt .= $self->Attribs->{term_set}[1]
-                . $tail
-                ;
+    if ( length $tail ) {
+        $prompt .= $self->Attribs->{term_set}[1] . $tail;
     }
+
     #say $self->_escape_str($prompt);
 
     return $prompt;
 }
 
-sub readline {
-    my ($self, $prompt) = @_;
+sub readline {    ## no critic (ProhibitBuiltinHomonyms)
+    my ( $self, $prompt ) = @_;
 
-    my %old_sig = $self->_set_signal_handlers;
+    local (%SIG) = %SIG;
+
+    $self->_set_signal_handlers;
 
     $prompt = $self->_prepare_prompt($prompt);
     $self->_set_ignore_keyboard_signals();
     my $input = $self->SUPER::readline($prompt);
     $self->_restore_keyboard_signals();
 
-    %SIG = %old_sig; # Restore signal handlers.
-
-    if (!$self->Features->{autohistory}) {
-        if (defined $input && length($input)) {
+    if ( !$self->Features->{autohistory} ) {
+        if ( defined $input && length($input) ) {
             $self->AddHistory($input);
         }
     }
@@ -233,11 +240,12 @@ sub readline {
 # face of various signals (^C ^\ ^Z).
 #
 sub _set_signal_handlers {
+    ## no critic (RequireLocalizedPunctuationVars)
     my $self = shift;
 
-    my %old_sig = %SIG;
+    my %old_SIG = %SIG;
 
-    my $last_sig = '';
+    my $most_recent_signal = q{};
 
     # The generic signal handler will attempt to re-throw the signal, after
     # putting the terminal in the correct state. Any previously set signal
@@ -246,12 +254,13 @@ sub _set_signal_handlers {
         my ($signal) = @_;
 
         my $this_handler = $SIG{$signal};
-        my $handler = $old_sig{$signal} // '';
+        my $handler      = $old_SIG{$signal} // q{};
 
         $self->deprep_terminal();
         $self->_restore_keyboard_signals();
 
-        if ($handler eq '' or $handler eq 'DEFAULT') {
+        if ( $handler eq q{} or $handler eq 'DEFAULT' ) {
+
             # We've de-prepped the terminal, now reset the signal handler
             # and re-issue the signal. Since we're inside a signal handler
             # the re-thrown signal will be deferred until we return from
@@ -263,10 +272,10 @@ sub _set_signal_handlers {
             return;
         }
 
-        if (ref $handler) {
-            # Call old signal handler and re-prep the terminal.
-            local($SIG{$signal}) = $handler;
-            $handler->($signal, @_);
+        # Call old signal handler and re-prep the terminal.
+        if ( ref $handler ) {
+            local ( $SIG{$signal} ) = $handler;
+            $handler->( $signal, @_ );
         }
 
         $self->prep_terminal(1);
@@ -275,9 +284,9 @@ sub _set_signal_handlers {
         return;
     };
 
-    if ($self->ReadLine =~ /::Gnu$/) {
+    if ( $self->ReadLine =~ /::Gnu$/x ) {
         for my $sig (qw( HUP QUIT ALRM TERM )) {
-            $SIG{$sig} = $generic_handler if ref $old_sig{$sig};
+            $SIG{$sig} = $generic_handler if ref $old_SIG{$sig};
         }
     }
     else {
@@ -288,10 +297,10 @@ sub _set_signal_handlers {
     # the generic one: we abort the current input line.
     $SIG{INT} = sub {
         my ($signal) = @_;
-        if ($self->ReadLine =~ /::Gnu$/) {
+        if ( $self->ReadLine =~ /::Gnu$/x ) {
             $self->crlf;
         }
-        $self->replace_line('');
+        $self->replace_line(q{});
         $generic_handler->($signal);
         return 1;
     };
@@ -300,73 +309,75 @@ sub _set_signal_handlers {
     # In case we get suspended, make sure we redraw the CLI on wake-up.
     $SIG{CONT} = sub {
         my ($signal) = @_;
-        $last_sig = $signal;
-        $old_sig{$signal}->(@_) if ref $old_sig{$signal};
+        $most_recent_signal = $signal;
+        $old_SIG{$signal}->(@_) if ref $old_SIG{$signal};
         $self->_set_ignore_keyboard_signals();
         return 1;
     };
 
+    # GNU readline will call the signal_event_hook after handling
+    # a signal, so use this to force a display update after a 'CONT'
+    # signal.
     $self->Attribs->{signal_event_hook} = sub {
-        if ($last_sig eq 'CONT') {
+        if ( $most_recent_signal eq 'CONT' ) {
             $self->forced_update_display();
         }
+        $most_recent_signal = '';
         return 1;
     };
 
-    return %old_sig;
+    return %old_SIG;
 }
 
-
 # Install stubs for common GRL methods.
 sub _install_stubs {
     my ($self) = @_;
 
-    return $self if $self->ReadLine =~ /::Gnu$/;
+    return $self if $self->ReadLine =~ /::Gnu$/x;
 
-    no warnings 'once';
+    no warnings 'once';    ## no critic (ProhibitNoWarnings)
 
     *{free_line_state} = sub { };
     *{crlf}            = sub { $self->OUT->print("\n") };
 
     *{get_screen_size} = sub {
-        my ($width, $height) = Term::ReadKey::GetTerminalSize($Term_FH);
-        return ($height, $width);
+        my ( $width, $height ) = Term::ReadKey::GetTerminalSize($Term_FH);
+        return ( $height, $width );
     };
 
-    if ($self->ReadLine !~ /::Perl$/) {
-        *{replace_line} =
-        *{prep_terminal} =
-        *{deprep_terminal} =
-        *{forced_update_display} = sub { };
+    if ( $self->ReadLine !~ /::Perl$/x ) {
+        *{replace_line} = *{prep_terminal} = *{deprep_terminal} =
+            *{forced_update_display} = sub { };
 
         return $self;
     }
 
-    *{replace_line} = \&_perl_replace_line;
-    *{prep_terminal} = \&_perl_prep_terminal;
-    *{deprep_terminal} = \&_perl_deprep_terminal;
+    *{replace_line}          = \&_perl_replace_line;
+    *{prep_terminal}         = \&_perl_prep_terminal;
+    *{deprep_terminal}       = \&_perl_deprep_terminal;
     *{forced_update_display} = \&_perl_forced_update_display;
 
     return $self;
 }
 
 # Term::ReadLine::Perl implementations of GRL methods.
-sub _perl_prep_terminal         { readline::SetTTY() }
-sub _perl_deprep_terminal       { readline::ResetTTY() }
-sub _perl_forced_update_display { readline::redisplay() }
+sub _perl_prep_terminal         { readline::SetTTY();    return; }
+sub _perl_deprep_terminal       { readline::ResetTTY();  return; }
+sub _perl_forced_update_display { readline::redisplay(); return; }
 
 sub _perl_replace_line {
-    my ($self, $line) = @_;
-    $line //= '';
+    my ( $self, $line ) = @_;
+    $line //= q{};
+    ## no critic (ProhibitPackageVars)
     $readline::line = $line;
-    $readline::D = length($line) if $readline::D > length($line);
+    $readline::D    = length($line) if $readline::D > length($line);
     return;
 }
 
 sub ReadHistory {
-    my ($self, $hist_file) = @_;
+    my ( $self, $hist_file ) = @_;
 
-    if ($self->Features->{'readHistory'}) {
+    if ( $self->Features->{'readHistory'} ) {
         return $self->SUPER::ReadHistory($hist_file);
     }
 
@@ -374,7 +385,7 @@ sub ReadHistory {
 
     my @history;
     while (<$fh>) {
-        next if /^$/;
+        next if $_ eq "\n";
         chomp;
         shift @history if @history == $History_Size;
         push @history, $_;
@@ -386,40 +397,42 @@ sub ReadHistory {
 }
 
 sub WriteHistory {
-    my ($self, $hist_file) = @_;
+    my ( $self, $hist_file ) = @_;
 
-    if ($self->Features->{'writeHistory'}) {
+    if ( $self->Features->{'writeHistory'} ) {
         return $self->SUPER::WriteHistory($hist_file);
     }
 
     open my $fh, '>', $hist_file or return;
-    print $fh map { "$_\n" } $self->term->GetHistory or return;
-    $fh->close or return;
+    print $fh map {"$_\n"} $self->term->GetHistory or return;
+    $fh->close                                     or return;
     return 1;
 }
 
 *{stifle_history} = \&StifleHistory;
-sub StifleHistory {
-    my ($self, $max) = @_;
 
-    if ($self->Features->{'stiflehistory'}) {
+sub StifleHistory {
+    my ( $self, $max ) = @_;
+
+    if ( $self->Features->{'stiflehistory'} ) {
         return $self->SUPER::StifleHistory($max);
     }
 
-    $max //= 1e12;
+    $max //= $HIST_LIMIT;
     $max = 0 if $max <= 0;
 
-    if ($self->ReadLine =~ /::Perl$/) {
+    if ( $self->ReadLine =~ /::Perl$/x ) {
+        ## no critic (ProhibitPackageVars)
         $readline::rl_MaxHistorySize = $max;
         my $cur = int @readline::rl_History;
-        if ($cur > $max) {
-            splice(@readline::rl_History, 0, -$max);
-            $readline::rl_HistoryIndex -= ($cur - $max);
+        if ( $cur > $max ) {
+            splice( @readline::rl_History, 0, -$max );
+            $readline::rl_HistoryIndex -= ( $cur - $max );
         }
         return $max;
     }
 
-    splice(@History, 0, -$max) if @History > $max;
+    splice( @History, 0, -$max ) if @History > $max;
     $History_Size = $max;
     return $max;
 }
@@ -427,18 +440,18 @@ sub StifleHistory {
 sub GetHistory {
     my ($self) = @_;
 
-    if ($self->Features->{'getHistory'}) {
+    if ( $self->Features->{'getHistory'} ) {
         return $self->SUPER::GetHistory();
     }
     return @History;
 }
 
 sub SetHistory {
-    my ($self, @l) = @_;
+    my ( $self, @l ) = @_;
 
-    splice(@l, 0, -$History_Size) if @l > $History_Size;
+    splice( @l, 0, -$History_Size ) if @l > $History_Size;
 
-    if ($self->Features->{'setHistory'}) {
+    if ( $self->Features->{'setHistory'} ) {
         return $self->SUPER::SetHistory(@l);
     }
 
@@ -448,18 +461,17 @@ sub SetHistory {
 }
 
 sub AddHistory {
-    my ($self, @lines) = @_;
+    my ( $self, @lines ) = @_;
 
-    if ($self->Features->{'addHistory'}) {
+    if ( $self->Features->{'addHistory'} ) {
         return $self->SUPER::AddHistory(@lines);
     }
 
     push @History, @lines;
-    splice(@History, 0, -$History_Size) if int(@History) > $History_Size;
+    splice( @History, 0, -$History_Size ) if int(@History) > $History_Size;
     return;
 }
 
-}
 1;
 
 __END__
@@ -472,7 +484,7 @@ Term::CLI::ReadLine - Term::ReadLine compatibility layer for Term::CLI
 
 =head1 VERSION
 
-version 0.053006
+version 0.054001
 
 =head1 SYNOPSIS
 
